@@ -60,7 +60,7 @@ import urllib.request
 from xml.etree.ElementTree import ElementTree
 from xml.parsers.expat import ExpatError
 
-if 'DISPLAY' not in os.environ or platform.system() == 'Windows':
+if platform.system() == 'Windows':
     # Curses is not available on Windows
     CURSES_AVAILABLE = False
 else:
